@@ -9,8 +9,14 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
+
 #include "utils.h"
 
+#ifndef __APPLE__
+  #include <sys/vfs.h>
+#endif
+
+
 /**
  * 对两个主机序的ipv4地址进行排序.
  * @param ip1 ipv4(host byte order)
@@ -129,6 +135,10 @@ char *convert_encode_copy(const char *string, const char *tocode, const char *fr
  */
 void get_file_system_info(const char *path, int64_t *avail, int64_t *total)
 {
+    #ifdef __APPLE__
+        *avail = *total = 0;
+    #else
+
         struct statfs64 st;
         int result;
 
@@ -143,6 +153,7 @@ mark:   switch (result = statfs64(path, &st)) {
                 *avail = *total = 0;
                 break;
         }
+    #endif
 }
 
 /**
