@@ -14,11 +14,11 @@
 
 #include "sys.h"
 
-void *operator new(size_t size);
-
 ssize_t xwrite(int fd, const void *buf, size_t count);
 ssize_t xread(int fd, void *buf, size_t count);
 ssize_t read_ipmsg_prefix(int fd, void *buf, size_t count);
+ssize_t read_ipmsg_filedata(int fd, void *buf, size_t count, size_t offset);
+ssize_t read_ipmsg_dirfiles(int fd, void *buf, size_t count, size_t offset);
 ssize_t read_ipmsg_fileinfo(int fd, void *buf, size_t count, size_t offset);
 
 #endif
